/**
 * Copyright 1998-2007, CHISEL Group, University of Victoria, Victoria, BC, Canada.
 * All rights reserved.
 */
package ca.uvic.csr.shrimp.adapter;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.Iterator;
import java.util.Vector;

import ca.uvic.csr.shrimp.SelectorBeanConstants;
import ca.uvic.csr.shrimp.DisplayBean.ShrimpNode;
import ca.uvic.csr.shrimp.DisplayBean.PFlatDisplayBean.PFlatDisplayBean;
import ca.uvic.csr.shrimp.SelectorBean.SelectorBean;
import ca.uvic.csr.shrimp.ShrimpApplication.BeanNotFoundException;
import ca.uvic.csr.shrimp.ShrimpTool.ShrimpTool;
import ca.uvic.csr.shrimp.gui.HierarchicalView.HierarchicalView;
import ca.uvic.csr.shrimp.gui.HierarchicalView.HvSvBridge;
import ca.uvic.csr.shrimp.gui.ShrimpView.ShrimpView;
import ca.uvic.csr.shrimp.util.CollectionUtils;

/**
 * Accentuates all nodes in the hierarchical view that are selected in a given selector bean.
 * 
 * @author Rob Lintern
 */
public class HvSelectedNodesChangeAdapter implements PropertyChangeListener {

	private HierarchicalView hierarchicalView;
	private ShrimpView shrimpView;
	
	public HvSelectedNodesChangeAdapter(ShrimpView shrimpView, HierarchicalView hierarchicalView) {
		this.shrimpView = shrimpView;
		this.hierarchicalView = hierarchicalView;
	}
	
	/**
	 * Accentuates all nodes in the hierarchical view that are selected in a selector bean.
	 */
	public void propertyChange(PropertyChangeEvent evt) {
		Vector oldSelected = (Vector) evt.getOldValue();
		Vector newSelected = (Vector) evt.getNewValue();
		if (CollectionUtils.haveSameElements(oldSelected, newSelected)) 
			return;
	
		SelectorBean svSelectorBean = null;
		PFlatDisplayBean flatDisplayBean = null;
		try {				
			flatDisplayBean = (PFlatDisplayBean) hierarchicalView.getBean(ShrimpTool.DISPLAY_BEAN);
			svSelectorBean = (SelectorBean) shrimpView.getBean(ShrimpTool.SELECTOR_BEAN);				
		} catch (BeanNotFoundException e) {
			return;
		}	
		
		if (hierarchicalView.getCurrentDisplayMode() != HierarchicalView.NAVIGATION_MODE) 
			return;		
		
		flatDisplayBean.clearAccentuated();
		
		Vector oldHvSelectedNodes = HvSvBridge.svNodesToHvNodes(hierarchicalView, shrimpView, oldSelected, false);
		for (Iterator iter = oldHvSelectedNodes.iterator(); iter.hasNext();) {
			ShrimpNode oldHvNode = (ShrimpNode) iter.next();
			flatDisplayBean.accentuateMouseOver(oldHvNode, false);
		}
		
		// accentuate hier view nodes that are selected in ShrimpView
		Vector svSelectedNodes = (Vector)svSelectorBean.getSelected(SelectorBeanConstants.SELECTED_NODES);
		if (svSelectedNodes != null) {
			// convert shrimp view nodes to hierarchical view nodes
			Vector hvNodes = HvSvBridge.svNodesToHvNodes(hierarchicalView, shrimpView, svSelectedNodes, false);
			flatDisplayBean.accentuate(hvNodes, true);
			for (Iterator iter = hvNodes.iterator(); iter.hasNext();) {
				ShrimpNode hvNode = (ShrimpNode) iter.next();
				flatDisplayBean.accentuateMouseOver(hvNode, true);
			}
		}
	}

}
