/**
 * Copyright 1998-2007, CHISEL Group, University of Victoria, Victoria, BC, Canada.
 * All rights reserved.
 */
package ca.uvic.csr.shrimp.gui;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.net.URL;

import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JDialog;
import javax.swing.JEditorPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;

import ca.uvic.csr.shrimp.ShrimpApplication.ApplicationAccessor;
import ca.uvic.csr.shrimp.ShrimpApplication.ShrimpApplication;

/**
 * Displays a dialog window outlining quick ways to get up and running with Shrimp.
 * 
 * @author Neil Ernst, Chris Callendar
 */
public class ShowQuickStartDialog {

	private URL fileURL;	
	
	/**
	 * @param fileURL the URL of the quick start help page
	 */
	public ShowQuickStartDialog(URL fileURL) {
		this.fileURL = fileURL;
	}

	/**
	 * Shows the quick start dialog (doesn't check the app preferences).
	 */
	public void showDialog() {	
		final ShrimpApplication app = ApplicationAccessor.getApplication();
		final JDialog dialog = new JDialog(app.getParentFrame(), "Getting Started in " + app.getName());
		dialog.setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);
		dialog.getContentPane().setLayout(new BorderLayout());
		
		//add text pane
		JEditorPane editorPane = createEditorPane();
		JScrollPane sp = new JScrollPane(editorPane, JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
		sp.setPreferredSize(new Dimension(600, 565));
		sp.setWheelScrollingEnabled(true);
		dialog.getContentPane().add(sp, BorderLayout.CENTER);
		
		JPanel pnlButtons = new JPanel (new BorderLayout());
		//add checkbox to dialog
		final JCheckBox checkBox = new JCheckBox ("Do not show this again.");	
		checkBox.setPreferredSize(new Dimension(200, 35));
		pnlButtons.add(checkBox, BorderLayout.WEST);		
		
		//add dismiss button
		JButton dismissBtn = new JButton("Dismiss");
		dismissBtn.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent arg0) {
				app.getProperties().setProperty(ShrimpApplication.SHOW_QUICKSTART_DIALOG_KEY, "" + !checkBox.isSelected());
				dialog.dispose();
			}
		});
		dismissBtn.setPreferredSize(new Dimension(100, 35));
		pnlButtons.add(dismissBtn, BorderLayout.EAST);
		
		dialog.getContentPane().add(pnlButtons, BorderLayout.SOUTH);
				
		// put dialog in center of screen
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
		dialog.setLocation((int)(screenSize.getWidth()/2.0 - 250.0), (int) (screenSize.getHeight()/2.0 - 300.0));
		dialog.setPreferredSize(new Dimension(600, 600));
		dialog.setModal(true);
		dialog.pack();
        try {
			if (fileURL != null) {
				editorPane.setPage(fileURL);
			} else {
				throw new NullPointerException("Invalid URL");
			}
		} catch (Exception e) {
		    editorPane.setText("Couldn't load HTML file " + fileURL + ".\n" + e.getMessage());
		}
		dialog.getRootPane().setDefaultButton(dismissBtn);
		dialog.setVisible(true);	// blocks here
	}
	
	/**
	 * Loads the content in off the web
	 */
    private JEditorPane createEditorPane() {
        JEditorPane editorPane = new JEditorPane();
        editorPane.setEditable(false);
        editorPane.setPreferredSize(new Dimension(480, 565));
        editorPane.setText("loading...");
		return editorPane;
    }

}
